from os import getenv

DEBUG = True
SECRET_KEY = "xem*6no%8d9%^qzt2f3x3ar-uq4_+7h9myc$t0!+4%bj5us6f)"
WIALON_ADMIN_ID = getenv("WIALON_ADMIN_ID")
WIALON_TOKEN = getenv("WIALON_TOKEN")
MERCHANT_AUTH_LOGIN_ID = getenv("MERCHANT_AUTH_LOGIN_ID")
MERCHANT_AUTH_TRANSACTION_KEY = getenv("MERCHANT_AUTH_TRANSACTION_KEY")
QB_CLIENT_ID = getenv("QB_CLIENT_ID")
QB_CLIENT_SECRET = getenv("QB_CLIENT_ID")
